/*
 * Copyright (C) 2017-2021 the xine project
 *
 * This file is part of xine, a free video player.
 *
 * xine is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * xine is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110, USA
 *
 * simple network input plugins
 */

#include <xine/xine_internal.h>

void *input_net_init_class  (xine_t *xine, const void *data);
void *input_tls_init_class  (xine_t *xine, const void *data);
void *input_gopher_init_class(xine_t *xine, const void *data);
void *input_http_init_class (xine_t *xine, const void *data);
void *input_rtsp_init_class (xine_t *xine, const void *data);
void *input_pnm_init_class  (xine_t *xine, const void *data);
void *input_ftp_init_class  (xine_t *xine, const void *data);
void *input_ftpes_init_class(xine_t *xine, const void *data);
void *input_hls_init_class  (xine_t *xine, const void *data);
void *input_mpegdash_init_class (xine_t *xine, const void *data);
